@@ -18,7 +18,6 @@
 """
 Lyceum journal content classes.
 """
-from BTrees.OOBTree import OOBTree
 from decimal import Decimal
 from persistent import Persistent
 
@@ -56,6 +55,7 @@ from schooltool.requirement.evaluation import Evaluation
 from schooltool.requirement.scoresystem import AbstractScoreSystem
 from schooltool.requirement.scoresystem import GlobalRangedValuesScoreSystem
 from schooltool.requirement.scoresystem import CustomScoreSystem
+from schooltool.requirement.scoresystem import PersistentRangedValuesScoreSystem
 from schooltool.requirement.scoresystem import ScoreValidationError, UNSCORED
 from schooltool.requirement.interfaces import IScoreSystemContainer
 from schooltool.securitypolicy.crowds import ConfigurableCrowd
@@ -521,10 +521,8 @@ class SectionJournal(object):
 
     def gradedMeetings(self, person, requirement_factory=GradeRequirement):
         meetings = []
-        for section in self.adjacent_sections:
-            sd = ISectionJournalData(section)
-            meetings.extend(sd.gradedMeetings(
-                    person, requirement_factory=requirement_factory))
+        sd = ISectionJournalData(removeSecurityProxy(self.section))
+        meetings = sd.gradedMeetings(person, requirement_factory)
         return sorted(meetings)
 
     def absentMeetings(self, person):
@@ -629,10 +627,14 @@ def getScoreSystemPreferences(jd):
 class JournalScoreSystemsStartup(StartUpBase):
 
     def updateGradingSS(self, prefs):
-        if prefs.grading_scoresystem is not None:
+        if (prefs.grading_scoresystem is not None and
+            not (isinstance(prefs.grading_scoresystem, PersistentRangedValuesScoreSystem)
+                 and prefs.grading_scoresystem.title == u'10 Points')):
             return
         app = ISchoolToolApplication(None)
         ssc = IScoreSystemContainer(app)
+        if prefs.grading_scoresystem is not None:
+            del ssc['ten_points']
         tenPointScoreSystem = CustomScoreSystem(
             u'10 Points', u'10 Points Score System',
             scores=[(unicode(i), u'', Decimal(i), Decimal((i-1)*10))
@@ -721,7 +723,7 @@ class JournalGradingScoreSystemChoices(zope.schema.vocabulary.SimpleVocabulary):
         result.append(self.createTerm(
                 None,
                 z3c.form.widget.SequenceWidget.noValueToken,
-                _("Select a scoresystem"),
+                _("Select a score system"),
                 ))
         scoresystems = self.getScoreSystems()
         for scoresystem in scoresystems:
